#ifndef USERSETTINGS_H
#define USERSETTINGS_H

#include "libcommon_global.h"

#include "settings.h"

#include <QSharedPointer>
#include <QVariantMap>


struct COMMONSHARED_EXPORT UserSettingsData {
    struct ScreenData {
        bool autorotationEnabled = false;
        Qt::ScreenOrientation lastOrientation = Qt::PrimaryOrientation;
    };

    const QVariantMap toVariantMap() const;
    static const UserSettingsData fromVariantMap(const QVariantMap& map);

    ScreenData defaultScreenData;
    QMap<QString, ScreenData> screensData;
};


class COMMONSHARED_EXPORT UserSettings : public Settings
{
    Q_OBJECT

public:
    explicit UserSettings(const QString& filePath,
                          const QSharedPointer<UserSettings>& defaultSettings = nullptr,
                          QObject* parent = nullptr);
    virtual ~UserSettings();

public:
    const QStringList screens();
    bool autorotationEnabled(const QString& screenName);
    void setAutorotation(const QString& screenName, const bool enable);
    Qt::ScreenOrientation lastOrientation(const QString& screenName);
    void setLastOrientation(const QString& screenName, const Qt::ScreenOrientation orientation);
    static const QString screenGroupName(const QString& screenName);

private:
    QSharedPointer<UserSettings> m_defaultSettings;
};

#endif // USERSETTINGS_H
